import React, { AnchorHTMLAttributes } from 'react';
import { MarginMixin, PaddingMixin } from '../../base/spacing';
import { textColors, textSizes, textWeights } from '../Text/Text';
export declare const hoverColors: {
    purpleCyan: string;
    yellowPink: string;
    cyanGreen: string;
    pinkPurple: string;
    cyan: string;
    green: string;
    orange: string;
    pink: string;
    purple: string;
    red: string;
    yellow: string;
    white: string;
    black: string;
    blackSecondary: string;
    blackLight: string;
};
/** Anchor Props */
export interface AnchorProps extends AnchorHTMLAttributes<HTMLAnchorElement>, PaddingMixin, MarginMixin {
    /**
     * The path to link this anchor to.
     */
    href?: string;
    /**
     * Controls the size of the link based on pre-configured Dracula UI sizes.
     */
    size?: keyof typeof textSizes;
    /**
     * Controls the weight of the link.
     */
    weight?: keyof typeof textWeights;
    /**
     * Controls the color of the link
     */
    color?: keyof typeof textColors;
    /**
     * Controls the color of the link on hover
     */
    hoverColor?: keyof typeof hoverColors;
    /**
     * Whether or not to apply external link props such as `target="_blank"` and `rel="noopener noreferrer"`
     */
    isExternal?: boolean;
}
/**
 * Anchor is an abstraction/style that can/is applied to HTML anchor elements.
 *
 * Consumers of this component can control, the color, size,
 * weight, and spacing of the Anchor.
 *
 * Use this component to create text or element based anchors around other HTML tags or React Components.
 */
export declare const Anchor: React.ForwardRefExoticComponent<AnchorProps & React.RefAttributes<HTMLAnchorElement>>;
