import React, { HTMLAttributes } from 'react';
import { MarginMixin, PaddingMixin } from '../../base/spacing';
export declare const textAligns: {
    left: string;
    center: string;
    right: string;
    justify: string;
};
export declare const textSizes: {
    md: string;
    lg: string;
    sm: string;
    xs: string;
};
export declare const textWeights: {
    normal: string;
    semibold: string;
    bold: string;
};
export declare const lineHeights: {
    md: string;
    xl: string;
    lg: string;
    sm: string;
    xs: string;
};
export declare const textColors: {
    purpleCyan: string;
    yellowPink: string;
    cyanGreen: string;
    pinkPurple: string;
    cyan: string;
    green: string;
    orange: string;
    pink: string;
    purple: string;
    red: string;
    yellow: string;
    white: string;
    black: string;
    blackSecondary: string;
    blackLight: string;
};
/** Text Props */
export interface TextProps extends HTMLAttributes<HTMLSpanElement>, PaddingMixin, MarginMixin {
    /**
     * Controls the alignment of text.
     */
    align?: keyof typeof textAligns;
    /**
     * Controls the size of the text based on pre-configured Dracula UI sizes.
     */
    size?: keyof typeof textSizes;
    /**
     * Controls the weight of the text.
     */
    weight?: keyof typeof textWeights;
    /**
     * Controls the line height of a text.
     */
    lineHeight?: keyof typeof lineHeights;
    /**
     * Controls the color of the text
     */
    color?: keyof typeof textColors;
    /** The HTML element to be used */
    as?: 'a' | 'span' | 'p';
}
/**
 * Text is the base component for any sort of text.
 *
 * Consumers of this component can control, the color, size,
 * weight, and spacing of Text.
 *
 * Use this component for generic, and non-hierarchical text that is
 * to be displayed on a page, or as part of other complex components
 * or UI patterns.
 */
export declare const Text: {
    (props: TextProps): React.DetailedReactHTMLElement<Pick<{
        className: string;
        defaultChecked?: boolean | undefined;
        defaultValue?: string | number | readonly string[] | undefined;
        suppressContentEditableWarning?: boolean | undefined;
        suppressHydrationWarning?: boolean | undefined;
        accessKey?: string | undefined;
        contentEditable?: boolean | "true" | "false" | "inherit" | undefined;
        contextMenu?: string | undefined;
        dir?: string | undefined;
        draggable?: boolean | "true" | "false" | undefined;
        hidden?: boolean | undefined;
        id?: string | undefined;
        lang?: string | undefined;
        placeholder?: string | undefined;
        slot?: string | undefined;
        spellCheck?: boolean | "true" | "false" | undefined;
        style?: React.CSSProperties | undefined;
        tabIndex?: number | undefined;
        title?: string | undefined;
        translate?: "yes" | "no" | undefined;
        radioGroup?: string | undefined;
        role?: "article" | "button" | "dialog" | "figure" | "form" | "img" | "link" | "main" | "menu" | "menuitem" | "option" | "table" | "none" | "alert" | "alertdialog" | "application" | "banner" | "cell" | "checkbox" | "columnheader" | "combobox" | "complementary" | "contentinfo" | "definition" | "directory" | "document" | "feed" | "grid" | "gridcell" | "group" | "heading" | "list" | "listbox" | "listitem" | "log" | "marquee" | "math" | "menubar" | "menuitemcheckbox" | "menuitemradio" | "navigation" | "note" | "presentation" | "progressbar" | "radio" | "radiogroup" | "region" | "row" | "rowgroup" | "rowheader" | "scrollbar" | "search" | "searchbox" | "separator" | "slider" | "spinbutton" | "status" | "switch" | "tab" | "tablist" | "tabpanel" | "term" | "textbox" | "timer" | "toolbar" | "tooltip" | "tree" | "treegrid" | "treeitem" | (string & {}) | undefined;
        about?: string | undefined;
        datatype?: string | undefined;
        inlist?: any;
        prefix?: string | undefined;
        property?: string | undefined;
        resource?: string | undefined;
        typeof?: string | undefined;
        vocab?: string | undefined;
        autoCapitalize?: string | undefined;
        autoCorrect?: string | undefined;
        autoSave?: string | undefined;
        itemProp?: string | undefined;
        itemScope?: boolean | undefined;
        itemType?: string | undefined;
        itemID?: string | undefined;
        itemRef?: string | undefined;
        results?: number | undefined;
        security?: string | undefined;
        unselectable?: "on" | "off" | undefined;
        inputMode?: "none" | "search" | "text" | "tel" | "url" | "email" | "numeric" | "decimal" | undefined;
        is?: string | undefined;
        'aria-activedescendant'?: string | undefined;
        'aria-atomic'?: boolean | "true" | "false" | undefined;
        'aria-autocomplete'?: "none" | "list" | "inline" | "both" | undefined;
        'aria-busy'?: boolean | "true" | "false" | undefined;
        'aria-checked'?: boolean | "true" | "false" | "mixed" | undefined;
        'aria-colcount'?: number | undefined;
        'aria-colindex'?: number | undefined;
        'aria-colspan'?: number | undefined;
        'aria-controls'?: string | undefined;
        'aria-current'?: boolean | "time" | "true" | "false" | "page" | "step" | "location" | "date" | undefined;
        'aria-describedby'?: string | undefined;
        'aria-details'?: string | undefined;
        'aria-disabled'?: boolean | "true" | "false" | undefined;
        'aria-dropeffect'?: "link" | "none" | "copy" | "execute" | "move" | "popup" | undefined;
        'aria-errormessage'?: string | undefined;
        'aria-expanded'?: boolean | "true" | "false" | undefined;
        'aria-flowto'?: string | undefined;
        'aria-grabbed'?: boolean | "true" | "false" | undefined;
        'aria-haspopup'?: boolean | "dialog" | "menu" | "true" | "false" | "grid" | "listbox" | "tree" | undefined;
        'aria-hidden'?: boolean | "true" | "false" | undefined;
        'aria-invalid'?: boolean | "true" | "false" | "grammar" | "spelling" | undefined;
        'aria-keyshortcuts'?: string | undefined;
        'aria-label'?: string | undefined;
        'aria-labelledby'?: string | undefined;
        'aria-level'?: number | undefined;
        'aria-live'?: "off" | "assertive" | "polite" | undefined;
        'aria-modal'?: boolean | "true" | "false" | undefined;
        'aria-multiline'?: boolean | "true" | "false" | undefined;
        'aria-multiselectable'?: boolean | "true" | "false" | undefined;
        'aria-orientation'?: "horizontal" | "vertical" | undefined;
        'aria-owns'?: string | undefined;
        'aria-placeholder'?: string | undefined;
        'aria-posinset'?: number | undefined;
        'aria-pressed'?: boolean | "true" | "false" | "mixed" | undefined;
        'aria-readonly'?: boolean | "true" | "false" | undefined;
        'aria-relevant'?: "text" | "additions" | "additions removals" | "additions text" | "all" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
        'aria-required'?: boolean | "true" | "false" | undefined;
        'aria-roledescription'?: string | undefined;
        'aria-rowcount'?: number | undefined;
        'aria-rowindex'?: number | undefined;
        'aria-rowspan'?: number | undefined;
        'aria-selected'?: boolean | "true" | "false" | undefined;
        'aria-setsize'?: number | undefined;
        'aria-sort'?: "none" | "ascending" | "descending" | "other" | undefined;
        'aria-valuemax'?: number | undefined;
        'aria-valuemin'?: number | undefined;
        'aria-valuenow'?: number | undefined;
        'aria-valuetext'?: string | undefined;
        children?: React.ReactNode;
        dangerouslySetInnerHTML?: {
            __html: string;
        } | undefined;
        onCopy?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onCopyCapture?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onCut?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onCutCapture?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onPaste?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onPasteCapture?: ((event: React.ClipboardEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionEnd?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionEndCapture?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionStart?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionStartCapture?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionUpdate?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onCompositionUpdateCapture?: ((event: React.CompositionEvent<HTMLSpanElement>) => void) | undefined;
        onFocus?: ((event: React.FocusEvent<HTMLSpanElement, Element>) => void) | undefined;
        onFocusCapture?: ((event: React.FocusEvent<HTMLSpanElement, Element>) => void) | undefined;
        onBlur?: ((event: React.FocusEvent<HTMLSpanElement, Element>) => void) | undefined;
        onBlurCapture?: ((event: React.FocusEvent<HTMLSpanElement, Element>) => void) | undefined;
        onChange?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onChangeCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onBeforeInput?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onBeforeInputCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onInput?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onInputCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onReset?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onResetCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onSubmit?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onSubmitCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onInvalid?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onInvalidCapture?: ((event: React.FormEvent<HTMLSpanElement>) => void) | undefined;
        onLoad?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onError?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onErrorCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onKeyDown?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onKeyDownCapture?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onKeyPress?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onKeyPressCapture?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onKeyUp?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onKeyUpCapture?: ((event: React.KeyboardEvent<HTMLSpanElement>) => void) | undefined;
        onAbort?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onAbortCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onCanPlay?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onCanPlayCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onCanPlayThrough?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onCanPlayThroughCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onDurationChange?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onDurationChangeCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEmptied?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEmptiedCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEncrypted?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEncryptedCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEnded?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onEndedCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadedData?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadedDataCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadedMetadata?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadedMetadataCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadStart?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onLoadStartCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPause?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPauseCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPlay?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPlayCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPlaying?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onPlayingCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onProgress?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onProgressCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onRateChange?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onRateChangeCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSeeked?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSeekedCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSeeking?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSeekingCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onStalled?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onStalledCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSuspend?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSuspendCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onTimeUpdate?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onTimeUpdateCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onVolumeChange?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onVolumeChangeCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onWaiting?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onWaitingCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onAuxClick?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onAuxClickCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onClick?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onClickCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onContextMenu?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onContextMenuCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onDoubleClick?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onDoubleClickCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onDrag?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragEnd?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragEndCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragEnter?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragEnterCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragExit?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragExitCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragLeave?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragLeaveCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragOver?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragOverCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragStart?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDragStartCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDrop?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onDropCapture?: ((event: React.DragEvent<HTMLSpanElement>) => void) | undefined;
        onMouseDown?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseDownCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseEnter?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseLeave?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseMove?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseMoveCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseOut?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseOutCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseOver?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseOverCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseUp?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onMouseUpCapture?: ((event: React.MouseEvent<HTMLSpanElement, MouseEvent>) => void) | undefined;
        onSelect?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onSelectCapture?: ((event: React.SyntheticEvent<HTMLSpanElement, Event>) => void) | undefined;
        onTouchCancel?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchCancelCapture?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchEnd?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchEndCapture?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchMove?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchMoveCapture?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchStart?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onTouchStartCapture?: ((event: React.TouchEvent<HTMLSpanElement>) => void) | undefined;
        onPointerDown?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerDownCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerMove?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerMoveCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerUp?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerUpCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerCancel?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerCancelCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerEnter?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerEnterCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerLeave?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerLeaveCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerOver?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerOverCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerOut?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onPointerOutCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onGotPointerCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onGotPointerCaptureCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onLostPointerCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onLostPointerCaptureCapture?: ((event: React.PointerEvent<HTMLSpanElement>) => void) | undefined;
        onScroll?: ((event: React.UIEvent<HTMLSpanElement, UIEvent>) => void) | undefined;
        onScrollCapture?: ((event: React.UIEvent<HTMLSpanElement, UIEvent>) => void) | undefined;
        onWheel?: ((event: React.WheelEvent<HTMLSpanElement>) => void) | undefined;
        onWheelCapture?: ((event: React.WheelEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationStart?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationStartCapture?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationEnd?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationEndCapture?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationIteration?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onAnimationIterationCapture?: ((event: React.AnimationEvent<HTMLSpanElement>) => void) | undefined;
        onTransitionEnd?: ((event: React.TransitionEvent<HTMLSpanElement>) => void) | undefined;
        onTransitionEndCapture?: ((event: React.TransitionEvent<HTMLSpanElement>) => void) | undefined;
        p?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        py?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        px?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        pt?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        pb?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        pl?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        pr?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | undefined;
        m?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        my?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        mx?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        mt?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        mb?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        ml?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
        mr?: "md" | "lg" | "sm" | "xs" | "none" | "xxs" | "auto" | undefined;
    }, "slot" | "style" | "title" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "hidden" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "translate" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "children" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture">, HTMLElement>;
    displayName: string;
};
